@@ -262,8 +262,7 @@ cups_setUser (PyObject *self, PyObject *args)
     return NULL;
 
   cupsSetUser (user);
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 static PyObject *
@@ -275,8 +274,7 @@ cups_setServer (PyObject *self, PyObject *args)
     return NULL;
 
   cupsSetServer (server);
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 static PyObject *
@@ -288,8 +286,7 @@ cups_setPort (PyObject *self, PyObject *args)
     return NULL;
 
   ippSetPort (port);
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 static PyObject *
@@ -300,8 +297,7 @@ cups_setEncryption (PyObject *self, PyObject *args)
     return NULL;
 
   cupsSetEncryption (e);
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 static PyObject *
@@ -359,8 +355,7 @@ cups_setPasswordCB (PyObject *self, PyObject *args)
 #endif
 
   debugprintf ("<- cups_setPasswordCB\n");
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 #ifdef HAVE_CUPS_1_4
@@ -404,8 +399,7 @@ cups_setPasswordCB2 (PyObject *self, PyObject *args)
   }
 
   debugprintf ("<- cups_setPasswordCB2\n");
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 #endif /* HAVE_CUPS_1_4 */
 
@@ -417,8 +411,7 @@ cups_ppdSetConformance (PyObject *self, PyObject *args)
     return NULL;
 
   ppdSetConformance (level);
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 static PyObject *
@@ -457,7 +450,7 @@ cups_require (PyObject *self, PyObject *args)
     nreq = strtoul (preq, &end, 0);
   }
 
-  return Py_None;
+  Py_RETURN_NONE;
 fail:
   PyErr_SetString (PyExc_RuntimeError, "I am version " VERSION);
   return NULL;
@@ -692,7 +685,9 @@ initcups (void)
   INT_CONSTANT (HTTP_SERVICE_UNAVAILABLE);
   INT_CONSTANT (HTTP_GATEWAY_TIMEOUT);
   INT_CONSTANT (HTTP_NOT_SUPPORTED);
+#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 4)
   INT_CONSTANT (HTTP_AUTHORIZATION_CANCELED);
+#endif /* CUPS 1.4 */
 #if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 5)
   INT_CONSTANT (HTTP_PKI_ERROR);
 #endif /* CUPS 1.5 */
