@@ -1,6 +1,6 @@
 /*
  * cups - Python bindings for CUPS
- * Copyright (C) 2002, 2005, 2006, 2007, 2008  Tim Waugh <twaugh@redhat.com>
+ * Copyright (C) 2002, 2005, 2006, 2007, 2008, 2011  Tim Waugh <twaugh@redhat.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -220,6 +220,7 @@ PPD_init (PPD *self, PyObject *args, PyObject *kwds)
     return -1;
   }
 
+  debugprintf ("+ PPD %p %s (fd %d)\n", self, filename, fileno (self->file));
   self->ppd = ppdOpenFile (filename);
   if (!self->ppd) {
     fclose (self->file);
@@ -235,6 +236,8 @@ PPD_init (PPD *self, PyObject *args, PyObject *kwds)
 static void
 PPD_dealloc (PPD *self)
 {
+  debugprintf ("- PPD %p (fd %d)\n", self, fileno (self->file));
+
   if (self->file)
     fclose (self->file);
   if (self->ppd)
@@ -255,7 +258,7 @@ static PyObject *
 PPD_localize (PPD *self)
 {
   if (!ppdLocalize (self->ppd))
-    return Py_None;
+    Py_RETURN_NONE;
   return PyErr_SetFromErrno (PyExc_RuntimeError);
 }
 
@@ -319,8 +322,7 @@ static PyObject *
 PPD_markDefaults (PPD *self)
 {
   ppdMarkDefaults (self->ppd);
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 static PyObject *
@@ -507,7 +509,7 @@ PPD_nondefaultsMarked (PPD *self)
   return PyBool_FromLong (nondefaults_marked);
 }
 
-#ifdef __SVR4
+#if !(_POSIX_C_SOURCE >= 200809L || _XOPEN_SOURCE >= 700)
 /*
  * A rudimentary emulation of getline() for systems that dont support it
  * natively.  Since this is used for PPD file reading, it assumes (possibly
@@ -549,11 +551,10 @@ PPD_emitString (PPD *self, PyObject *args)
     ret = PyString_FromString(emitted);
     free (emitted);
   } else {
+    Py_INCREF (Py_None);
     ret = Py_None;
   }
 
-  Py_INCREF (ret);
-
   return ret;
 }
 
@@ -576,7 +577,7 @@ PPD_emit (PPD *self, PyObject *args)
     return NULL;
 
   if (!ppdEmit(self->ppd, f, section))
-    return Py_None;
+    Py_RETURN_NONE;
   return PyErr_SetFromErrno (PyExc_RuntimeError);
 }
 
@@ -601,7 +602,7 @@ PPD_emitAfterOrder (PPD *self, PyObject *args)
     return NULL;
 
   if (!ppdEmitAfterOrder(self->ppd, f, section, limit, min_order))
-    return Py_None;
+    Py_RETURN_NONE;
   return PyErr_SetFromErrno (PyExc_RuntimeError);
 }
 
@@ -619,7 +620,7 @@ PPD_emitFd (PPD *self, PyObject *args)
     return NULL;
 
   if (!ppdEmitFd(self->ppd, f, section))
-    return Py_None;
+    Py_RETURN_NONE;
   return PyErr_SetFromErrno (PyExc_RuntimeError);
 }
 
@@ -644,7 +645,7 @@ PPD_emitJCL (PPD *self, PyObject *args)
     return NULL;
 
   if (!ppdEmitJCL(self->ppd, f, job_id, user, title))
-    return Py_None;
+    Py_RETURN_NONE;
   return PyErr_SetFromErrno (PyExc_RuntimeError);
 }
 
@@ -666,7 +667,7 @@ PPD_emitJCLEnd (PPD *self, PyObject *args)
     return NULL;
 
   if (!ppdEmitJCLEnd(self->ppd, f))
-    return Py_None;
+    Py_RETURN_NONE;
   return PyErr_SetFromErrno (PyExc_RuntimeError);
 }
 
@@ -736,8 +737,7 @@ PPD_writeFd (PPD *self, PyObject *args)
   if (line)
     free (line);
 
-  Py_INCREF (Py_None);
-  return Py_None;
+  Py_RETURN_NONE;
 }
 
 /////////
@@ -1080,8 +1080,7 @@ static PyObject *
 Option_getKeyword (Option *self, void *closure)
 {
   if (!self->option) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->option->keyword);
@@ -1091,8 +1090,7 @@ static PyObject *
 Option_getDefchoice (Option *self, void *closure)
 {
   if (!self->option) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->option->defchoice);
@@ -1102,8 +1100,7 @@ static PyObject *
 Option_getText (Option *self, void *closure)
 {
   if (!self->option) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->option->text);
@@ -1113,8 +1110,7 @@ static PyObject *
 Option_getUI (Option *self, void *closure)
 {
   if (!self->option) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return PyInt_FromLong (self->option->ui);
@@ -1312,8 +1308,7 @@ static PyObject *
 Group_getText (Group *self, void *closure)
 {
   if (!self->group) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->group->text);
@@ -1323,8 +1318,7 @@ static PyObject *
 Group_getName (Group *self, void *closure)
 {
   if (!self->group) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->group->name);
@@ -1500,8 +1494,7 @@ static PyObject *
 Constraint_getOption1 (Constraint *self, void *closure)
 {
   if (!self->constraint) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->constraint->option1);
@@ -1511,8 +1504,7 @@ static PyObject *
 Constraint_getChoice1 (Constraint *self, void *closure)
 {
   if (!self->constraint) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->constraint->choice1);
@@ -1522,8 +1514,7 @@ static PyObject *
 Constraint_getOption2 (Constraint *self, void *closure)
 {
   if (!self->constraint) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->constraint->option2);
@@ -1533,8 +1524,7 @@ static PyObject *
 Constraint_getChoice2 (Constraint *self, void *closure)
 {
   if (!self->constraint) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->constraint->choice2);
@@ -1662,8 +1652,7 @@ static PyObject *
 Attribute_getName (Attribute *self, void *closure)
 {
   if (!self->attribute) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->attribute->name);
@@ -1673,8 +1662,7 @@ static PyObject *
 Attribute_getSpec (Attribute *self, void *closure)
 {
   if (!self->attribute) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->attribute->spec);
@@ -1684,8 +1672,7 @@ static PyObject *
 Attribute_getText (Attribute *self, void *closure)
 {
   if (!self->attribute) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->attribute->text);
@@ -1695,8 +1682,7 @@ static PyObject *
 Attribute_getValue (Attribute *self, void *closure)
 {
   if (!self->attribute) {
-    Py_INCREF (Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
   }
 
   return make_PyUnicode_from_ppd_string (self->ppd, self->attribute->value);
